@@ -1,22 +1,20 @@
 # LIBS
-library(restez)
 library(testthat)
 
 # VARS
 nrcrds <- 10  # how many fake records to test on?
 wd <- getwd()
-data_d <- restez:::testdatadir_get()
+data_d <- testdatadir_get()
 
 # DATA
 records <- readRDS(file = file.path(data_d, 'records.RData'))
 
 # SETUP
-restez:::cleanup()
-restez:::setup()
-restez_connect()
-df <- restez:::gb_df_generate(records = sample(records, size = nrcrds))
+cleanup()
+setup()
+df <- gb_df_generate(records = sample(records, size = nrcrds))
 ids <- as.character(df[['accession']])
-restez:::gb_sql_add(df = df)
+gb_sql_add(df = df)
 
 # RUNNING
 context('Testing \'rentrez-wrappers\'')
@@ -34,4 +32,4 @@ test_that('entrez_fetch() works', {
   )
   expect_true(res)
 })
-restez:::cleanup()
+cleanup()
